@@ -125,7 +125,7 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 						Text:        symbol,
 					})
 			case "price":
-				text := humanize.Monetaryf(coin.Price, 2)
+				text := ct.FormatPrice(coin.Price)
 				symbolPadding := 1
 				ct.SetTableColumnWidth(header, utf8.RuneCountInString(text)+symbolPadding)
 				ct.SetTableColumnAlignLeft(header, false)
@@ -529,12 +529,25 @@ func (ct *Cointop) GetPortfolioSlice() []*Coin {
 		return sliced
 	}
 
+OUTER:
 	for i := range ct.State.allCoins {
 		coin := ct.State.allCoins[i]
 		p, isNew := ct.PortfolioEntry(coin)
 		if isNew {
 			continue
 		}
+		// check not already found
+		updateSlice := -1
+		for j := range sliced {
+			if coin.Symbol == sliced[j].Symbol {
+				if coin.Rank >= sliced[j].Rank {
+					continue OUTER // skip updates from lower-ranked coins
+				}
+				updateSlice = j // update this later
+				break
+			}
+		}
+
 		coin.Holdings = p.Holdings
 		balance := coin.Price * p.Holdings
 		balancestr := fmt.Sprintf("%.2f", balance)
@@ -543,7 +556,12 @@ func (ct *Cointop) GetPortfolioSlice() []*Coin {
 		}
 		balance, _ = strconv.ParseFloat(balancestr, 64)
 		coin.Balance = balance
-		sliced = append(sliced, coin)
+		if updateSlice == -1 {
+			sliced = append(sliced, coin)
+		} else {
+			sliced[updateSlice] = coin
+		}
+
 	}
 
 	sort.Slice(sliced, func(i, j int) bool {
@@ -718,7 +736,7 @@ func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
 				item[i] = entry.Symbol
 			case "price":
 				if humanReadable {
-					item[i] = fmt.Sprintf("%s%s", symbol, humanize.Monetaryf(entry.Price, 2))
+					item[i] = fmt.Sprintf("%s%s", symbol, ct.FormatPrice(entry.Price))
 				} else {
 					item[i] = strconv.FormatFloat(entry.Price, 'f', -1, 64)
 				}
